import { AbstractPowerSyncDatabaseOpenFactory } from '@journeyapps/powersync-sdk-common';
import { PowerSyncDatabase } from '../../db/PowerSyncDatabase';
import { SSRDBAdapter } from './SSRDBAdapter';
/**
 * Intermediate PowerSync Database Open factory for Web which uses a mock
 * SSR DB Adapter if running on server side.
 * Most SQLite DB implementations only run on client side, this will safely return
 * empty query results in SSR which will allow for generating server partial views.
 */
export class AbstractWebPowerSyncDatabaseOpenFactory extends AbstractPowerSyncDatabaseOpenFactory {
    isServerSide() {
        return typeof window == 'undefined';
    }
    constructor(options) {
        super(options);
        this.options = options;
    }
    generateOptions() {
        var _a, _b, _c;
        const isServerSide = this.isServerSide();
        if (isServerSide && !((_a = this.options.flags) === null || _a === void 0 ? void 0 : _a.disableSSRWarning)) {
            console.warn(`
  Running PowerSync in SSR mode.
  Only empty query results will be returned.
  Disable this warning by setting 'disableSSRWarning: true' in options.`);
        }
        if (!((_b = this.options.flags) === null || _b === void 0 ? void 0 : _b.enableMultiTabs)) {
            console.warn('Multiple tab support is not enabled. Using this site across multiple tabs may not function correctly.');
        }
        return {
            database: isServerSide ? new SSRDBAdapter() : this.openDB(),
            schema: this.schema,
            flags: {
                ssrMode: this.isServerSide(),
                enableMultiTabs: (_c = this.options.flags) === null || _c === void 0 ? void 0 : _c.enableMultiTabs
            }
        };
    }
    generateInstance(options) {
        return new PowerSyncDatabase(options);
    }
}
//# sourceMappingURL=AbstractWebPowerSyncDatabaseOpenFactory.js.map